@@ -150,7 +150,7 @@ is_valid_unix (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Unsupported key '%s' in address entry '%s'"),
+                       _("Unsupported key “%s” in address entry “%s”"),
                        key,
                        address_entry);
           goto out;
@@ -177,7 +177,7 @@ is_valid_unix (const gchar  *address_entry,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Address '%s' is invalid (need exactly one of path, tmpdir or abstract keys)"),
+                   _("Address “%s” is invalid (need exactly one of path, tmpdir or abstract keys)"),
                    address_entry);
       goto out;
     }
@@ -190,7 +190,7 @@ is_valid_unix (const gchar  *address_entry,
   g_set_error (error,
                G_IO_ERROR,
                G_IO_ERROR_INVALID_ARGUMENT,
-               _("Meaningless key/value pair combination in address entry '%s'"),
+               _("Meaningless key/value pair combination in address entry “%s”"),
                address_entry);
 
  out:
@@ -238,7 +238,7 @@ is_valid_nonce_tcp (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Unsupported key '%s' in address entry '%s'"),
+                       _("Unsupported key “%s” in address entry “%s”"),
                        key,
                        address_entry);
           goto out;
@@ -253,7 +253,7 @@ is_valid_nonce_tcp (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error in address '%s' - the port attribute is malformed"),
+                       _("Error in address “%s” — the port attribute is malformed"),
                        address_entry);
           goto out;
         }
@@ -264,7 +264,7 @@ is_valid_nonce_tcp (const gchar  *address_entry,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Error in address '%s' - the family attribute is malformed"),
+                   _("Error in address “%s” — the family attribute is malformed"),
                    address_entry);
       goto out;
     }
@@ -319,7 +319,7 @@ is_valid_tcp (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Unsupported key '%s' in address entry '%s'"),
+                       _("Unsupported key “%s” in address entry “%s”"),
                        key,
                        address_entry);
           goto out;
@@ -334,7 +334,7 @@ is_valid_tcp (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error in address '%s' - the port attribute is malformed"),
+                       _("Error in address “%s” — the port attribute is malformed"),
                        address_entry);
           goto out;
         }
@@ -345,7 +345,7 @@ is_valid_tcp (const gchar  *address_entry,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Error in address '%s' - the family attribute is malformed"),
+                   _("Error in address “%s” — the family attribute is malformed"),
                    address_entry);
       goto out;
     }
@@ -454,7 +454,7 @@ _g_dbus_address_parse_entry (const gchar  *address_entry,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Address element '%s' does not contain a colon (:)"),
+                   _("Address element “%s” does not contain a colon (:)"),
                    address_entry);
       goto out;
     }
@@ -475,7 +475,7 @@ _g_dbus_address_parse_entry (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Key/Value pair %d, '%s', in address element '%s' does not contain an equal sign"),
+                       _("Key/Value pair %d, “%s”, in address element “%s” does not contain an equal sign"),
                        n,
                        kv_pair,
                        address_entry);
@@ -489,7 +489,7 @@ _g_dbus_address_parse_entry (const gchar  *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error unescaping key or value in Key/Value pair %d, '%s', in address element '%s'"),
+                       _("Error unescaping key or value in Key/Value pair %d, “%s”, in address element “%s”"),
                        n,
                        kv_pair,
                        address_entry);
@@ -567,8 +567,8 @@ g_dbus_address_connect (const gchar   *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error in address '%s' - the unix transport requires exactly one of the "
-                         "keys 'path' or 'abstract' to be set"),
+                       _("Error in address “%s” — the unix transport requires exactly one of the "
+                         "keys “path” or “abstract” to be set"),
                        address_entry);
         }
       else if (path != NULL)
@@ -603,7 +603,7 @@ g_dbus_address_connect (const gchar   *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error in address '%s' - the host attribute is missing or malformed"),
+                       _("Error in address “%s” — the host attribute is missing or malformed"),
                        address_entry);
           goto out;
         }
@@ -617,7 +617,7 @@ g_dbus_address_connect (const gchar   *address_entry,
           g_set_error (error,
                        G_IO_ERROR,
                        G_IO_ERROR_INVALID_ARGUMENT,
-                       _("Error in address '%s' - the port attribute is missing or malformed"),
+                       _("Error in address “%s” — the port attribute is missing or malformed"),
                        address_entry);
           goto out;
         }
@@ -631,7 +631,7 @@ g_dbus_address_connect (const gchar   *address_entry,
               g_set_error (error,
                            G_IO_ERROR,
                            G_IO_ERROR_INVALID_ARGUMENT,
-                           _("Error in address '%s' - the noncefile attribute is missing or malformed"),
+                           _("Error in address “%s” — the noncefile attribute is missing or malformed"),
                            address_entry);
               goto out;
             }
@@ -660,7 +660,7 @@ g_dbus_address_connect (const gchar   *address_entry,
       g_set_error (error,
                    G_IO_ERROR,
                    G_IO_ERROR_INVALID_ARGUMENT,
-                   _("Unknown or unsupported transport '%s' for address '%s'"),
+                   _("Unknown or unsupported transport “%s” for address “%s”"),
                    transport_name,
                    address_entry);
     }
@@ -696,7 +696,7 @@ g_dbus_address_connect (const gchar   *address_entry,
               g_set_error (error,
                            G_IO_ERROR,
                            G_IO_ERROR_INVALID_ARGUMENT,
-                           _("Error opening nonce file '%s': %s"),
+                           _("Error opening nonce file “%s”: %s"),
                            nonce_file,
                            g_strerror (errno));
               g_object_unref (ret);
@@ -714,7 +714,7 @@ g_dbus_address_connect (const gchar   *address_entry,
                   g_set_error (error,
                                G_IO_ERROR,
                                G_IO_ERROR_INVALID_ARGUMENT,
-                               _("Error reading from nonce file '%s': %s"),
+                               _("Error reading from nonce file “%s”: %s"),
                                nonce_file,
                                g_strerror (errno));
                 }
@@ -723,7 +723,7 @@ g_dbus_address_connect (const gchar   *address_entry,
                   g_set_error (error,
                                G_IO_ERROR,
                                G_IO_ERROR_INVALID_ARGUMENT,
-                               _("Error reading from nonce file '%s', expected 16 bytes, got %d"),
+                               _("Error reading from nonce file “%s”, expected 16 bytes, got %d"),
                                nonce_file,
                                (gint) num_bytes_read);
                 }
@@ -741,7 +741,7 @@ g_dbus_address_connect (const gchar   *address_entry,
                                           cancellable,
                                           error))
             {
-              g_prefix_error (error, _("Error writing contents of nonce file '%s' to stream:"), nonce_file);
+              g_prefix_error (error, _("Error writing contents of nonce file “%s” to stream:"), nonce_file);
               g_object_unref (ret);
               ret = NULL;
               goto out;
@@ -1117,7 +1117,7 @@ get_session_address_dbus_launch (GError **error)
 
   if (!g_spawn_check_exit_status (exit_status, error))
     {
-      g_prefix_error (error, _("Error spawning command line '%s': "), command_line);
+      g_prefix_error (error, _("Error spawning command line “%s”: "), command_line);
       goto out;
     }
 
@@ -1633,7 +1633,7 @@ g_dbus_address_get_for_bus_sync (GBusType       bus_type,
                            G_IO_ERROR,
                            G_IO_ERROR_FAILED,
                            _("Cannot determine bus address from DBUS_STARTER_BUS_TYPE environment variable"
-                             " - unknown value '%s'"),
+                             " — unknown value “%s”"),
                            starter_bus);
             }
           else
