@@ -40,7 +40,10 @@
  * (g_input_stream_skip()). 
  *
  * To copy the content of an input stream to an output stream without 
- * manually handling the reads and writes, use g_output_stream_splice(). 
+ * manually handling the reads and writes, use g_output_stream_splice().
+ *
+ * See the documentation for #GIOStream for details of thread safety of
+ * streaming APIs.
  *
  * All of these functions have async variants too.
  **/
@@ -182,7 +185,7 @@ g_input_stream_read  (GInputStream  *stream,
   if (class->read_fn == NULL) 
     {
       g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-                           _("Input stream doesn't implement read"));
+                           _("Input stream doesn’t implement read"));
       return -1;
     }
 
@@ -780,6 +783,7 @@ g_input_stream_read_all_async (GInputStream        *stream,
   data->buffer = buffer;
   data->to_read = count;
 
+  g_task_set_source_tag (task, g_input_stream_read_all_async);
   g_task_set_task_data (task, data, free_async_read_all);
   g_task_set_priority (task, io_priority);
 
@@ -916,6 +920,8 @@ g_input_stream_read_bytes_async (GInputStream          *stream,
   guchar *buf;
 
   task = g_task_new (stream, cancellable, callback, user_data);
+  g_task_set_source_tag (task, g_input_stream_read_bytes_async);
+
   buf = g_malloc (count);
   g_task_set_task_data (task, buf, NULL);
 
@@ -1231,7 +1237,7 @@ g_input_stream_clear_pending (GInputStream *stream)
   stream->priv->pending = FALSE;
 }
 
-/**
+/*< internal >
  * g_input_stream_async_read_is_via_threads:
  * @stream: input stream
  *
@@ -1253,6 +1259,26 @@ g_input_stream_async_read_is_via_threads (GInputStream *stream)
         g_pollable_input_stream_can_poll (G_POLLABLE_INPUT_STREAM (stream))));
 }
 
+/*< internal >
+ * g_input_stream_async_close_is_via_threads:
+ * @stream: input stream
+ *
+ * Checks if an input stream's close_async function uses threads.
+ *
+ * Returns: %TRUE if @stream's close_async function uses threads.
+ **/
+gboolean
+g_input_stream_async_close_is_via_threads (GInputStream *stream)
+{
+  GInputStreamClass *class;
+
+  g_return_val_if_fail (G_IS_INPUT_STREAM (stream), FALSE);
+
+  class = G_INPUT_STREAM_GET_CLASS (stream);
+
+  return class->close_async == g_input_stream_real_close_async;
+}
+
 /********************************************
  *   Default implementation of async ops    *
  ********************************************/
@@ -1355,6 +1381,7 @@ g_input_stream_real_read_async (GInputStream        *stream,
   
   op = g_slice_new0 (ReadData);
   task = g_task_new (stream, cancellable, callback, user_data);
+  g_task_set_source_tag (task, g_input_stream_real_read_async);
   g_task_set_task_data (task, op, (GDestroyNotify) free_read_data);
   g_task_set_priority (task, io_priority);
   op->buffer = buffer;
@@ -1466,6 +1493,7 @@ g_input_stream_real_skip_async (GInputStream        *stream,
   class = G_INPUT_STREAM_GET_CLASS (stream);
 
   task = g_task_new (stream, cancellable, callback, user_data);
+  g_task_set_source_tag (task, g_input_stream_real_skip_async);
   g_task_set_priority (task, io_priority);
 
   if (g_input_stream_async_read_is_via_threads (stream))
@@ -1541,6 +1569,7 @@ g_input_stream_real_close_async (GInputStream        *stream,
   GTask *task;
 
   task = g_task_new (stream, cancellable, callback, user_data);
+  g_task_set_source_tag (task, g_input_stream_real_close_async);
   g_task_set_check_cancellable (task, FALSE);
   g_task_set_priority (task, io_priority);
   
