@@ -245,7 +245,7 @@ end_element (GMarkupParseContext  *context,
 	  if (real_file == NULL && state->collect_data)
 	    {
 		g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-			     _("Failed to locate '%s' in any source directory"), file);
+			     _("Failed to locate “%s” in any source directory"), file);
 		return;
 	    }
 	}
@@ -256,7 +256,7 @@ end_element (GMarkupParseContext  *context,
 	  if (!exists && state->collect_data)
 	    {
 	      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-			   _("Failed to locate '%s' in current directory"), file);
+			   _("Failed to locate “%s” in current directory"), file);
 	      return;
 	    }
 	}
@@ -287,7 +287,7 @@ end_element (GMarkupParseContext  *context,
               else
                 {
                   g_set_error (error, G_MARKUP_ERROR, G_MARKUP_ERROR_INVALID_CONTENT,
-                               _("Unknown processing option \"%s\""), options[i]);
+                               _("Unknown processing option “%s”"), options[i]);
                   g_strfreev (options);
                   goto cleanup;
                 }
@@ -626,8 +626,8 @@ main (int argc, char **argv)
     { "generate-source", 0, 0, G_OPTION_ARG_NONE, &generate_source, N_("Generate sourcecode used to link in the resource file into your code"), NULL },
     { "generate-dependencies", 0, 0, G_OPTION_ARG_NONE, &generate_dependencies, N_("Generate dependency list"), NULL },
     { "dependency-file", 0, 0, G_OPTION_ARG_FILENAME, &dependency_file, N_("name of the dependency file to generate"), N_("FILE") },
-    { "manual-register", 0, 0, G_OPTION_ARG_NONE, &manual_register, N_("Don't automatically create and register resource"), NULL },
-    { "internal", 0, 0, G_OPTION_ARG_NONE, &internal, N_("Don't export functions; declare them G_GNUC_INTERNAL"), NULL },
+    { "manual-register", 0, 0, G_OPTION_ARG_NONE, &manual_register, N_("Don’t automatically create and register resource"), NULL },
+    { "internal", 0, 0, G_OPTION_ARG_NONE, &internal, N_("Don’t export functions; declare them G_GNUC_INTERNAL"), NULL },
     { "c-name", 0, 0, G_OPTION_ARG_STRING, &c_name, N_("C identifier name used for the generated source code"), NULL },
     { NULL }
   };
@@ -748,68 +748,74 @@ main (int argc, char **argv)
       return 1;
     }
 
-  if (generate_dependencies || dependency_file != NULL)
+  /* This can be used in the same invocation
+     as other generate commands */
+  if (dependency_file != NULL)
+    {
+      /* Generate a .d file that describes the dependencies for
+       * build tools, gcc -M -MF style */
+      GString *dep_string;
+      GHashTableIter iter;
+      gpointer key, data;
+      FileData *file_data;
+
+      g_hash_table_iter_init (&iter, files);
+
+      dep_string = g_string_new (NULL);
+      g_string_printf (dep_string, "%s:", srcfile);
+
+      /* First rule: foo.xml: resource1 resource2.. */
+      while (g_hash_table_iter_next (&iter, &key, &data))
+        {
+          file_data = data;
+          if (!g_str_equal (file_data->filename, srcfile))
+            g_string_append_printf (dep_string, " %s", file_data->filename);
+        }
+
+      g_string_append (dep_string, "\n\n");
+
+      /* One rule for every resource: resourceN: */
+      g_hash_table_iter_init (&iter, files);
+      while (g_hash_table_iter_next (&iter, &key, &data))
+        {
+          file_data = data;
+          if (!g_str_equal (file_data->filename, srcfile))
+            g_string_append_printf (dep_string, "%s:\n\n", file_data->filename);
+        }
+
+      if (g_str_equal (dependency_file, "-"))
+        {
+          g_print ("%s\n", dep_string->str);
+        }
+      else
+        {
+          if (!g_file_set_contents (dependency_file, dep_string->str, dep_string->len, &error))
+            {
+              g_printerr ("Error writing dependency file: %s\n", error->message);
+              g_string_free (dep_string, TRUE);
+              g_free (dependency_file);
+              g_error_free (error);
+              return 1;
+            }
+        }
+
+      g_string_free (dep_string, TRUE);
+      g_free (dependency_file);
+    }
+
+  if (generate_dependencies)
     {
       GHashTableIter iter;
       gpointer key, data;
       FileData *file_data;
 
       g_hash_table_iter_init (&iter, files);
-      if (dependency_file == NULL)
+
+      /* Generate list of files for direct use as dependencies in a Makefile */
+      while (g_hash_table_iter_next (&iter, &key, &data))
         {
-          /* Generate list of files for direct use as dependencies in a Makefile */
-          while (g_hash_table_iter_next (&iter, &key, &data))
-            {
-              file_data = data;
-              g_print ("%s\n", file_data->filename);
-            }
-        }
-      else
-        {
-          /* Generate a .d file that describes the dependencies for
-           * build tools, gcc -M -MF style */
-          GString *dep_string;
-
-          dep_string = g_string_new (NULL);
-          g_string_printf (dep_string, "%s:", srcfile);
-
-          /* First rule: foo.xml: resource1 resource2.. */
-          while (g_hash_table_iter_next (&iter, &key, &data))
-            {
-              file_data = data;
-              if (!g_str_equal (file_data->filename, srcfile))
-                g_string_append_printf (dep_string, " %s", file_data->filename);
-            }
-
-          g_string_append (dep_string, "\n\n");
-
-          /* One rule for every resource: resourceN: */
-          g_hash_table_iter_init (&iter, files);
-          while (g_hash_table_iter_next (&iter, &key, &data))
-            {
-              file_data = data;
-              if (!g_str_equal (file_data->filename, srcfile))
-                g_string_append_printf (dep_string, "%s:\n\n", file_data->filename);
-            }
-
-          if (g_str_equal (dependency_file, "-"))
-            {
-              g_print ("%s\n", dep_string->str);
-            }
-          else
-            {
-              if (!g_file_set_contents (dependency_file, dep_string->str, dep_string->len, &error))
-                {
-                  g_printerr ("Error writing dependency file: %s\n", error->message);
-                  g_string_free (dep_string, TRUE);
-                  g_free (dependency_file);
-                  g_error_free (error);
-                  return 1;
-                }
-            }
-
-          g_string_free (dep_string, TRUE);
-          g_free (dependency_file);
+          file_data = data;
+          g_print ("%s\n", file_data->filename);
         }
     }
   else if (generate_source || generate_header)
