@@ -772,7 +772,7 @@ set_xattr (char                       *filename,
     {
       g_set_error (error, G_IO_ERROR,
 		   g_io_error_from_errno (errsv),
-		   _("Error setting extended attribute '%s': %s"),
+		   _("Error setting extended attribute “%s”: %s"),
 		   escaped_attribute, g_strerror (errsv));
       return FALSE;
     }
@@ -1096,10 +1096,8 @@ lookup_uid_data (uid_t uid)
 
   data = g_new0 (UidData, 1);
 
-#if defined(HAVE_POSIX_GETPWUID_R)
+#if defined(HAVE_GETPWUID_R)
   getpwuid_r (uid, &pwbuf, buffer, sizeof(buffer), &pwbufp);
-#elif defined(HAVE_NONPOSIX_GETPWUID_R)
-  pwbufp = getpwuid_r (uid, &pwbuf, buffer, sizeof(buffer));
 #else
   pwbufp = getpwuid (uid);
 #endif
@@ -1184,10 +1182,8 @@ lookup_gid_name (gid_t gid)
   if (name)
     return name;
 
-#if defined (HAVE_POSIX_GETGRGID_R)
+#if defined (HAVE_GETGRGID_R)
   getgrgid_r (gid, &gbuf, buffer, sizeof(buffer), &gbufp);
-#elif defined (HAVE_NONPOSIX_GETGRGID_R)
-  gbufp = getgrgid_r (gid, &gbuf, buffer, sizeof(buffer));
 #else
   gbufp = getgrgid (gid);
 #endif
@@ -1767,7 +1763,7 @@ _g_local_file_info_get (const char             *basename,
           g_object_unref (info);
           g_set_error (error, G_IO_ERROR,
 		       g_io_error_from_errno (errsv),
-		       _("Error when getting information for file '%s': %s"),
+		       _("Error when getting information for file “%s”: %s"),
 		       display_name, g_strerror (errsv));
           g_free (display_name);
           return NULL;
