@@ -390,7 +390,7 @@ g_mount_unmount (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement unmount. */
-                               _("mount doesn't implement \"unmount\""));
+                               _("mount doesn’t implement “unmount”"));
       return;
     }
   
@@ -466,7 +466,7 @@ g_mount_eject (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement eject. */
-                               _("mount doesn't implement \"eject\""));
+                               _("mount doesn’t implement “eject”"));
       return;
     }
   
@@ -544,7 +544,7 @@ g_mount_unmount_with_operation (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement any of unmount or unmount_with_operation. */
-                               _("mount doesn't implement \"unmount\" or \"unmount_with_operation\""));
+                               _("mount doesn’t implement “unmount” or “unmount_with_operation”"));
       return;
     }
 
@@ -629,7 +629,7 @@ g_mount_eject_with_operation (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement any of eject or eject_with_operation. */
-                               _("mount doesn't implement \"eject\" or \"eject_with_operation\""));
+                               _("mount doesn’t implement “eject” or “eject_with_operation”"));
       return;
     }
 
@@ -717,7 +717,7 @@ g_mount_remount (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement remount. */
-                               _("mount doesn't implement \"remount\""));
+                               _("mount doesn’t implement “remount”"));
       return;
     }
   
@@ -767,7 +767,8 @@ g_mount_remount_finish (GMount        *mount,
  * Tries to guess the type of content stored on @mount. Returns one or
  * more textual identifiers of well-known content types (typically
  * prefixed with "x-content/"), e.g. x-content/image-dcf for camera 
- * memory cards. See the <ulink url="http://www.freedesktop.org/wiki/Specifications/shared-mime-info-spec">shared-mime-info</ulink>
+ * memory cards. See the 
+ * [shared-mime-info](http://www.freedesktop.org/wiki/Specifications/shared-mime-info-spec)
  * specification for more on x-content types.
  *
  * This is an asynchronous operation (see
@@ -798,7 +799,7 @@ g_mount_guess_content_type (GMount              *mount,
                                /* Translators: This is an error
                                 * message for mount objects that
                                 * don't implement content type guessing. */
-                               _("mount doesn't implement content type guessing"));
+                               _("mount doesn’t implement content type guessing"));
       return;
     }
   
@@ -854,7 +855,8 @@ g_mount_guess_content_type_finish (GMount        *mount,
  * Tries to guess the type of content stored on @mount. Returns one or
  * more textual identifiers of well-known content types (typically
  * prefixed with "x-content/"), e.g. x-content/image-dcf for camera 
- * memory cards. See the <ulink url="http://www.freedesktop.org/wiki/Specifications/shared-mime-info-spec">shared-mime-info</ulink>
+ * memory cards. See the 
+ * [shared-mime-info](http://www.freedesktop.org/wiki/Specifications/shared-mime-info-spec)
  * specification for more on x-content types.
  *
  * This is an synchronous operation and as such may block doing IO;
@@ -884,7 +886,7 @@ g_mount_guess_content_type_sync (GMount              *mount,
                            /* Translators: This is an error
                             * message for mount objects that
                             * don't implement content type guessing. */
-                           _("mount doesn't implement synchronous content type guessing"));
+                           _("mount doesn’t implement synchronous content type guessing"));
 
       return NULL;
     }
@@ -944,10 +946,10 @@ get_private (GMount *mount)
  * situation, a #GVolumeMonitor implementation would create two
  * #GVolume objects (for example, one for the camera functionality of
  * the device and one for a SD card reader on the device) with
- * activation URIs <literal>gphoto2://[usb:001,002]/store1/</literal>
- * and <literal>gphoto2://[usb:001,002]/store2/</literal>. When the
+ * activation URIs `gphoto2://[usb:001,002]/store1/`
+ * and `gphoto2://[usb:001,002]/store2/`. When the
  * underlying mount (with root
- * <literal>gphoto2://[usb:001,002]/</literal>) is mounted, said
+ * `gphoto2://[usb:001,002]/`) is mounted, said
  * #GVolumeMonitor implementation would create two #GMount objects
  * (each with their root matching the corresponding volume activation
  * root) that would shadow the original mount.
