@@ -26,7 +26,6 @@
 #include "gnetworkingprivate.h"
 #include "gasyncresult.h"
 #include "ginetaddress.h"
-#include "gsimpleasyncresult.h"
 #include "gtask.h"
 #include "gsrvtarget.h"
 #include "gthreadedresolver.h"
@@ -73,10 +72,13 @@ struct _GResolverPrivate {
  *
  * The object that handles DNS resolution. Use g_resolver_get_default()
  * to get the default resolver.
+ *
+ * This is an abstract type; subclasses of it implement different resolvers for
+ * different platforms and situations.
  */
-G_DEFINE_TYPE_WITH_CODE (GResolver, g_resolver, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (GResolver)
-			 g_networking_init ();)
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GResolver, g_resolver, G_TYPE_OBJECT,
+                                  G_ADD_PRIVATE (GResolver)
+                                  g_networking_init ();)
 
 static GList *
 srv_records_to_targets (GList *records)
@@ -183,6 +185,7 @@ g_resolver_init (GResolver *resolver)
 #endif
 }
 
+G_LOCK_DEFINE_STATIC (default_resolver);
 static GResolver *default_resolver;
 
 /**
@@ -199,10 +202,15 @@ static GResolver *default_resolver;
 GResolver *
 g_resolver_get_default (void)
 {
+  GResolver *ret;
+
+  G_LOCK (default_resolver);
   if (!default_resolver)
     default_resolver = g_object_new (G_TYPE_THREADED_RESOLVER, NULL);
+  ret = g_object_ref (default_resolver);
+  G_UNLOCK (default_resolver);
 
-  return g_object_ref (default_resolver);
+  return ret;
 }
 
 /**
@@ -224,9 +232,11 @@ g_resolver_get_default (void)
 void
 g_resolver_set_default (GResolver *resolver)
 {
+  G_LOCK (default_resolver);
   if (default_resolver)
     g_object_unref (default_resolver);
   default_resolver = g_object_ref (resolver);
+  G_UNLOCK (default_resolver);
 }
 
 /* Bionic has res_init() but it's not in any header */
@@ -294,6 +304,7 @@ handle_ip_address (const char  *hostname,
                    GError     **error)
 {
   GInetAddress *addr;
+
 #ifndef G_OS_WIN32
   struct in_addr ip4addr;
 #endif
@@ -307,21 +318,30 @@ handle_ip_address (const char  *hostname,
 
   *addrs = NULL;
 
+#ifdef G_OS_WIN32
+
+  /* Reject IPv6 addresses that have brackets ('[' or ']') and/or port numbers,
+   * as no valid addresses should contain these at this point.
+   * Non-standard IPv4 addresses would be rejected during the call to
+   * getaddrinfo() later.
+   */
+  if (strrchr (hostname, '[') != NULL ||
+      strrchr (hostname, ']') != NULL)
+#else
+
   /* Reject non-standard IPv4 numbers-and-dots addresses.
    * g_inet_address_new_from_string() will have accepted any "real" IP
    * address, so if inet_aton() succeeds, then it's an address we want
-   * to reject.  This check is not necessary for Windows, as getaddrinfo()
-   * already rejects such IPv4 addresses on Windows.
+   * to reject.
    */
-#ifndef G_OS_WIN32
   if (inet_aton (hostname, &ip4addr))
+#endif
     {
       g_set_error (error, G_RESOLVER_ERROR, G_RESOLVER_ERROR_NOT_FOUND,
-                   _("Error resolving '%s': %s"),
+                   _("Error resolving “%s”: %s"),
                    hostname, gai_strerror (EAI_NONAME));
       return TRUE;
     }
-#endif
 
   return FALSE;
 }
