@@ -767,7 +767,7 @@ g_socket_client_class_init (GSocketClientClass *class)
    * @client: the #GSocketClient
    * @event: the event that is occurring
    * @connectable: the #GSocketConnectable that @event is occurring on
-   * @connection: the current representation of the connection
+   * @connection: (nullable): the current representation of the connection
    *
    * Emitted when @client's activity on @connectable changes state.
    * Among other things, this can be used to provide progress
@@ -1067,7 +1067,6 @@ g_socket_client_connect (GSocketClient       *client,
 	  GProxy *proxy;
 
 	  protocol = g_proxy_address_get_protocol (proxy_addr);
-	  proxy = g_proxy_get_default_for_protocol (protocol);
 
           /* The connection should not be anything else then TCP Connection,
            * but let's put a safety guard in case
@@ -1084,7 +1083,11 @@ g_socket_client_connect (GSocketClient       *client,
 	      g_object_unref (connection);
 	      connection = NULL;
             }
-          else if (proxy)
+	  else if (g_hash_table_contains (client->priv->app_proxies, protocol))
+	    {
+	      application_proxy = TRUE;
+	    }
+          else if ((proxy = g_proxy_get_default_for_protocol (protocol)))
 	    {
 	      GIOStream *proxy_connection;
 
@@ -1101,19 +1104,14 @@ g_socket_client_connect (GSocketClient       *client,
 	      if (connection)
 		g_socket_client_emit_event (client, G_SOCKET_CLIENT_PROXY_NEGOTIATED, connectable, connection);
 	    }
-	  else if (!g_hash_table_lookup_extended (client->priv->app_proxies,
-						  protocol, NULL, NULL))
+	  else
 	    {
 	      g_set_error (&last_error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-			   _("Proxy protocol '%s' is not supported."),
+			   _("Proxy protocol “%s” is not supported."),
 			   protocol);
 	      g_object_unref (connection);
 	      connection = NULL;
 	    }
-	  else
-	    {
-	      application_proxy = TRUE;
-	    }
 	}
 
       if (!application_proxy && connection && client->priv->tls)
@@ -1492,6 +1490,12 @@ g_socket_client_connected_callback (GObject      *source,
   GProxy *proxy;
   const gchar *protocol;
 
+  if (g_task_return_error_if_cancelled (data->task))
+    {
+      g_object_unref (data->task);
+      return;
+    }
+
   if (!g_socket_connection_connect_finish (G_SOCKET_CONNECTION (source),
 					   result, &error))
     {
@@ -1517,7 +1521,6 @@ g_socket_client_connected_callback (GObject      *source,
     }
 
   protocol = g_proxy_address_get_protocol (data->proxy_addr);
-  proxy = g_proxy_get_default_for_protocol (protocol);
 
   /* The connection should not be anything other than TCP,
    * but let's put a safety guard in case
@@ -1533,7 +1536,13 @@ g_socket_client_connected_callback (GObject      *source,
 
       enumerator_next_async (data);
     }
-  else if (proxy)
+  else if (g_hash_table_contains (data->client->priv->app_proxies, protocol))
+    {
+      /* Simply complete the connection, we don't want to do TLS handshake
+       * as the application proxy handling may need proxy handshake first */
+      g_socket_client_async_connect_complete (data);
+    }
+  else if ((proxy = g_proxy_get_default_for_protocol (protocol)))
     {
       g_socket_client_emit_event (data->client, G_SOCKET_CLIENT_PROXY_NEGOTIATING, data->connectable, data->connection);
       g_proxy_connect_async (proxy,
@@ -1544,23 +1553,16 @@ g_socket_client_connected_callback (GObject      *source,
                              data);
       g_object_unref (proxy);
     }
-  else if (!g_hash_table_lookup_extended (data->client->priv->app_proxies,
-					  protocol, NULL, NULL))
+  else
     {
       g_clear_error (&data->last_error);
 
       g_set_error (&data->last_error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-          _("Proxy protocol '%s' is not supported."),
+          _("Proxy protocol “%s” is not supported."),
           protocol);
 
       enumerator_next_async (data);
     }
-  else
-    {
-      /* Simply complete the connection, we don't want to do TLS handshake
-       * as the application proxy handling may need proxy handshake first */
-      g_socket_client_async_connect_complete (data);
-    }
 }
 
 static void
@@ -1677,6 +1679,7 @@ g_socket_client_connect_async (GSocketClient       *client,
     data->enumerator = g_socket_connectable_enumerate (connectable);
 
   data->task = g_task_new (client, cancellable, callback, user_data);
+  g_task_set_source_tag (data->task, g_socket_client_connect_async);
   g_task_set_task_data (data->task, data, (GDestroyNotify)g_socket_client_async_connect_data_free);
 
   enumerator_next_async (data);
@@ -1920,5 +1923,5 @@ void
 g_socket_client_add_application_proxy (GSocketClient *client,
 			               const gchar   *protocol)
 {
-  g_hash_table_insert (client->priv->app_proxies, g_strdup (protocol), NULL);
+  g_hash_table_add (client->priv->app_proxies, g_strdup (protocol));
 }
