@@ -40,6 +40,8 @@
  * subclasses, #GTlsClientConnection and #GTlsServerConnection,
  * implement client-side and server-side TLS, respectively.
  *
+ * For DTLS (Datagram TLS) support, see #GDtlsConnection.
+ *
  * Since: 2.28
  */
 
@@ -95,7 +97,11 @@ g_tls_connection_class_init (GTlsConnectionClass *klass)
   /**
    * GTlsConnection:base-io-stream:
    *
-   * The #GIOStream that the connection wraps
+   * The #GIOStream that the connection wraps. The connection holds a reference
+   * to this stream, and may run operations on the stream from other threads
+   * throughout its lifetime. Consequently, after the #GIOStream has been
+   * constructed, application code may only run its own operations on this
+   * stream when no #GIOStream operations are running.
    *
    * Since: 2.28
    */
@@ -200,7 +206,7 @@ g_tls_connection_class_init (GTlsConnectionClass *klass)
   g_object_class_install_property (gobject_class, PROP_CERTIFICATE,
 				   g_param_spec_object ("certificate",
 							P_("Certificate"),
-							P_("The connection's certificate"),
+							P_("The connection’s certificate"),
 							G_TYPE_TLS_CERTIFICATE,
 							G_PARAM_READWRITE |
 							G_PARAM_STATIC_STRINGS));
@@ -220,7 +226,7 @@ g_tls_connection_class_init (GTlsConnectionClass *klass)
   g_object_class_install_property (gobject_class, PROP_PEER_CERTIFICATE,
 				   g_param_spec_object ("peer-certificate",
 							P_("Peer Certificate"),
-							P_("The connection's peer's certificate"),
+							P_("The connection’s peer’s certificate"),
 							G_TYPE_TLS_CERTIFICATE,
 							G_PARAM_READABLE |
 							G_PARAM_STATIC_STRINGS));
@@ -239,7 +245,7 @@ g_tls_connection_class_init (GTlsConnectionClass *klass)
   g_object_class_install_property (gobject_class, PROP_PEER_CERTIFICATE_ERRORS,
 				   g_param_spec_flags ("peer-certificate-errors",
 						       P_("Peer Certificate Errors"),
-						       P_("Errors found with the peer's certificate"),
+						       P_("Errors found with the peer’s certificate"),
 						       G_TYPE_TLS_CERTIFICATE_FLAGS,
 						       0,
 						       G_PARAM_READABLE |
@@ -621,7 +627,8 @@ g_tls_connection_get_peer_certificate_errors (GTlsConnection *conn)
  * on @conn, this will send a close notification regardless of the
  * setting of this property. If you explicitly want to do an unclean
  * close, you can close @conn's #GTlsConnection:base-io-stream rather
- * than closing @conn itself.
+ * than closing @conn itself, but note that this may only be done when no other
+ * operations are pending on @conn or the base I/O stream.
  *
  * Since: 2.28
  */
