@@ -64,6 +64,7 @@
 #endif
 
 #include "gunixmounts.h"
+#include "glocalfileprivate.h"
 #include "gfile.h"
 #include "gfilemonitor.h"
 #include "glibintl.h"
@@ -1443,6 +1444,40 @@ g_unix_mount_at (const char *mount_path,
   return found;
 }
 
+/**
+ * g_unix_mount_for: (skip)
+ * @file_path: file path on some unix mount.
+ * @time_read: (out) (allow-none): guint64 to contain a timestamp.
+ *
+ * Gets a #GUnixMountEntry for a given file path. If @time_read
+ * is set, it will be filled with a unix timestamp for checking
+ * if the mounts have changed since with g_unix_mounts_changed_since().
+ *
+ * Returns: (transfer full): a #GUnixMountEntry.
+ *
+ * Since: 2.52
+ **/
+GUnixMountEntry *
+g_unix_mount_for (const char *file_path,
+                  guint64    *time_read)
+{
+  GUnixMountEntry *entry;
+
+  g_return_val_if_fail (file_path != NULL, NULL);
+
+  entry = g_unix_mount_at (file_path, time_read);
+  if (entry == NULL)
+    {
+      char *topdir;
+
+      topdir = _g_local_file_find_topdir_for (file_path);
+      entry = g_unix_mount_at (topdir, time_read);
+      g_free (topdir);
+    }
+
+  return entry;
+}
+
 /**
  * g_unix_mount_points_get: (skip)
  * @time_read: (out) (allow-none): guint64 to contain a timestamp.
@@ -1637,17 +1672,17 @@ mount_monitor_start (void)
       const gchar *mtab_path;
 
       mtab_path = get_mtab_monitor_file ();
-      /* /proc/mounts monitoring is special - can't just use GFileMonitor.
+      /* Monitoring files in /proc/ is special - can't just use GFileMonitor.
        * See 'man proc' for more details.
        */
-      if (g_strcmp0 (mtab_path, "/proc/mounts") == 0)
+      if (g_str_has_prefix (mtab_path, "/proc/"))
         {
           GIOChannel *proc_mounts_channel;
           GError *error = NULL;
-          proc_mounts_channel = g_io_channel_new_file ("/proc/mounts", "r", &error);
+          proc_mounts_channel = g_io_channel_new_file (mtab_path, "r", &error);
           if (proc_mounts_channel == NULL)
             {
-              g_warning ("Error creating IO channel for /proc/mounts: %s (%s, %d)",
+              g_warning ("Error creating IO channel for %s: %s (%s, %d)", mtab_path,
                          error->message, g_quark_to_string (error->domain), error->code);
               g_error_free (error);
             }
