@@ -54,16 +54,31 @@
 #endif
 
 /* Every compiler that we target supports inlining, but some of them may
- * complain about it if we don't say "__inline".  If we have C99, then
- * we can use "inline" directly.  Otherwise, we say "__inline" to avoid
- * the warning.
+ * complain about it if we don't say "__inline".  If we have C99, or if
+ * we are using C++, then we can use "inline" directly.  Unfortunately
+ * Visual Studio does not support __STDC_VERSION__, so we need to check
+ * whether we are on Visual Studio 2013 or earlier to see that we need to
+ * say "__inline" in C mode.
+ * Otherwise, we say "__inline" to avoid the warning.
  */
 #define G_CAN_INLINE
-#if !defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199900)
-#undef inline
-#define inline __inline
+#ifndef __cplusplus
+# ifdef _MSC_VER
+#  if (_MSC_VER < 1900)
+#   define G_INLINE_DEFINE_NEEDED
+#  endif
+# elif !defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199900)
+#  define G_INLINE_DEFINE_NEEDED
+# endif
 #endif
 
+#ifdef G_INLINE_DEFINE_NEEDED
+# undef inline
+# define inline __inline
+#endif
+
+#undef G_INLINE_DEFINE_NEEDED
+
 /* For historical reasons we need to continue to support those who
  * define G_IMPLEMENT_INLINES to mean "don't implement this here".
  */
@@ -91,6 +106,10 @@
 #endif
 
 /* Clang feature detection: http://clang.llvm.org/docs/LanguageExtensions.html */
+#ifndef __has_attribute
+#define __has_attribute(x) 0
+#endif
+
 #ifndef __has_feature
 #define __has_feature(x) 0
 #endif
@@ -100,7 +119,7 @@
 #endif
 
 #if     (!defined(__clang__) && ((__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))) || \
-        (defined(__clang__) && __has_feature(__alloc_size__))
+        (defined(__clang__) && __has_attribute(__alloc_size__))
 #define G_GNUC_ALLOC_SIZE(x) __attribute__((__alloc_size__(x)))
 #define G_GNUC_ALLOC_SIZE2(x,y) __attribute__((__alloc_size__(x,y)))
 #else
@@ -292,7 +311,7 @@
  * fields through their offsets.
  */
 
-#if defined(__GNUC__)  && __GNUC__ >= 4
+#if (defined(__GNUC__)  && __GNUC__ >= 4) || defined (_MSC_VER)
 #define G_STRUCT_OFFSET(struct_type, member) \
       ((glong) offsetof (struct_type, member))
 #else
